@@ -60,16 +60,16 @@ char *strip_sign (char *p)
 void option_error (LINE_T * l, char *option, char *info)
 {
   if (option != NO_TEXT) {
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", strip_sign (option)) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "*at option \"%s\"", option) >= 0);
     if (info != NO_TEXT) {
-      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s, at argument \"%s\"", info, A68G (output_line)) >= 0);
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s, %s", A68G (output_line), info) >= 0);
     } else {
-      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "at argument \"%s\"", A68G (output_line)) >= 0);
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", A68G (output_line)) >= 0);
     }
   } else if (info != NO_TEXT) {
     ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", info) >= 0);
   } else {
-    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "at argument") >= 0);
+    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "in options") >= 0);
   }
   scan_error (l, NO_TEXT, A68G (edit_line));
 }
@@ -226,6 +226,7 @@ void default_options (MODULE_T * p)
   OPTION_REDUCTIONS (p) = A68G_FALSE;
   OPTION_REGRESSION_TEST (p) = A68G_FALSE;
   OPTION_RERUN (p) = A68G_FALSE;
+  OPTION_RESTART (p) = A68G_TRUE;
   OPTION_RUN (p) = A68G_FALSE;
   OPTION_RUN_SCRIPT (p) = A68G_FALSE;
   OPTION_SOURCE_LISTING (p) = A68G_FALSE;
@@ -295,11 +296,12 @@ void prune_echoes (OPTION_LIST_T * ol)
 {
   while (ol != NO_OPTION_LIST) {
     if (SCAN (ol) == SOURCE_SCAN (&A68G_JOB)) {
-      char *p = strip_sign (STR (ol));
+      char *full_option = STR (ol);
+      char *option = strip_sign (full_option);
 // ECHO echoes a string.
-      if (eq (p, "ECHO")) {
+      if (eq (option, "ECHO")) {
         {
-          char *car = strchr (p, '=');
+          char *car = strchr (option, '=');
           if (car != NO_TEXT) {
             io_close_tty_line ();
             ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", &car[1]) >= 0);
@@ -554,7 +556,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
     #endif
   }
   if (eq (q, "mathlib")) {
-    #if defined (HAVE_MATHLIB)
+    #if defined (HAVE_R_MATHLIB)
       return (A68G_TRUE);
     #else
       io_close_tty_line ();
@@ -614,7 +616,6 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
       FORWARD (i);
     } else {
       LINE_T *start_l = LINE (i);
-      char *start_c = STR (i);
       size_t n = strlen (STR (i));
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
       while (n > 0 && (IS_SPACE ((STR (i))[n - 1]) || (STR (i))[n - 1] == '#')) {
@@ -622,44 +623,45 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
       }
       if (!(PROCESSED (i))) {
 // Accept UNIX '-option [=] value'.
-        BOOL_T minus_sign = (BOOL_T) ((STR (i))[0] == '-');
-        char *p = strip_sign (STR (i));
+        char *full_option = STR (i);
+        BOOL_T minus_sign = (BOOL_T) (full_option[0] == '-');
+        char *option = strip_sign (full_option);
 // Reserved case.
-        if (!minus_sign && eq (p, "#")) {
+        if (!minus_sign && eq (option, "#")) {
           ;
         } 
 // Item without minus sign on command line, is a filename.
         else if (!minus_sign && cmd_line) {
           if (!name_set) {
-            FILE_INITIAL_NAME (&A68G_JOB) = new_string (p, NO_TEXT);
+            FILE_INITIAL_NAME (&A68G_JOB) = new_string (option, NO_TEXT);
             name_set = A68G_TRUE;
           } else {
-            option_error (NO_LINE, start_c, ERROR_MULTIPLE_SOURCE_FILES);
+            option_error (NO_LINE, full_option, ERROR_MULTIPLE_SOURCE_FILES);
           }
         }
 // Empty item '--' stops option processing.
-        else if (strcmp (p, "--") == 0) {
+        else if (strcmp (option, "--") == 0) {
           siga = A68G_FALSE;
         }
 // Empty item '-' is incorrect.
-        else if (strcmp (p, "-") == 0) {
-          option_error (start_l, start_c, ERROR_INVALID_OPTION);
+        else if (strcmp (option, "-") == 0) {
+          option_error (start_l, full_option, ERROR_INVALID_OPTION);
           siga = A68G_FALSE;
         }
 // ALGOL60STROPPING sets stropping to quote stropping.
-        else if (eq (p, "ALGOL60stropping")) {
+        else if (eq (option, "ALGOL60stropping")) {
           OPTION_STROPPING (&A68G_JOB) = QUOTE_STROPPING;
-        } else if (eq (p, "ALGOL60-stropping")) {
+        } else if (eq (option, "ALGOL60-stropping")) {
           OPTION_STROPPING (&A68G_JOB) = QUOTE_STROPPING;
         }
 // ASSERTIONS switches on/off the processing of assertions.
-        else if (eq (p, "Assertions")) {
+        else if (eq (option, "Assertions")) {
           OPTION_NODEMASK (&A68G_JOB) |= ASSERT_MASK;
-        } else if (eq (p, "NOAssertions") || eq (p, "NO-Assertions")) {
+        } else if (eq (option, "NOAssertions") || eq (option, "NO-Assertions")) {
           OPTION_NODEMASK (&A68G_JOB) &= ~ASSERT_MASK;
         }
 // APROPOS, HELP, INFO give online help.
-        else if ((eq (p, "APropos") || eq (p, "Help") || eq (p, "INfo")) && cmd_line) {
+        else if ((eq (option, "APropos") || eq (option, "Help") || eq (option, "INfo")) && cmd_line) {
           FORWARD (i);
           if (i != NO_OPTION_LIST && strcmp (STR (i), "=") == 0) {
             FORWARD (i);
@@ -672,32 +674,32 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           a68g_exit (EXIT_SUCCESS);
         }
 // BACKTRACE and NOBACKTRACE switch on/off stack backtracing.
-        else if (eq (p, "BACKtrace")) {
+        else if (eq (option, "BACKtrace")) {
           OPTION_BACKTRACE (&A68G_JOB) = A68G_TRUE;
-        } else if (eq (p, "NOBACKtrace") || eq (p, "NO-BACKtrace")) {
+        } else if (eq (option, "NOBACKtrace") || eq (option, "NO-BACKtrace")) {
           OPTION_BACKTRACE (&A68G_JOB) = A68G_FALSE;
         }
 // BRACKETS extends Algol 68 syntax for brackets.
-        else if (eq (p, "BRackets")) {
+        else if (eq (option, "BRackets")) {
           OPTION_BRACKETS (&A68G_JOB) = A68G_TRUE;
         }
 // BREAK switches on/off tracing of the running program.
-        else if (eq (p, "BReakpoint")) {
+        else if (eq (option, "BReakpoint")) {
           OPTION_NODEMASK (&A68G_JOB) |= BREAKPOINT_MASK;
-        } else if (eq (p, "NOBReakpoint") || eq (p, "NO-BReakpoint")) {
+        } else if (eq (option, "NOBReakpoint") || eq (option, "NO-BReakpoint")) {
           OPTION_NODEMASK (&A68G_JOB) &= ~BREAKPOINT_MASK;
         }
 // CHECK and NORUN just check for syntax.
-        else if (eq (p, "CHeck") || eq (p, "NORun") || eq (p, "NO-Run")) {
+        else if (eq (option, "CHeck") || eq (option, "NORun") || eq (option, "NO-Run")) {
           OPTION_CHECK_ONLY (&A68G_JOB) = A68G_TRUE;
         }
 // CLOCK times program execution.
-        else if (eq (p, "CLock")) {
+        else if (eq (option, "CLock")) {
           OPTION_CLOCK (&A68G_JOB) = A68G_TRUE;
         }
 // COMPILE switches on/off compilation.
-        else if (eq (p, "Compile")) {
-          #if defined (BUILD_LINUX) || defined (BUILD_BSD)
+        else if (eq (option, "Compile")) {
+          #if defined (BUILD_UNIX)
             OPTION_COMPILE (&A68G_JOB) = A68G_TRUE;
             OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
             if (OPTION_OPT_LEVEL (&A68G_JOB) < OPTIMISE_1) {
@@ -705,15 +707,19 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
             }
             OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_FALSE;
           #else
-            option_error (start_l, start_c, ERROR_PLATFORM);
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "NOCompile") || eq (option, "NO-Compile")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
+            OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_FALSE;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
           #endif
-        } else if (eq (p, "NOCompile") || eq (p, "NO-Compile")) {
-          OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
-          OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_FALSE;
         }
 // ECHO echoes a text, is treated later.
-        else if (eq (p, "ECHO")) {
-          if (strchr (p, '=') == NO_TEXT) {
+        else if (eq (option, "ECHO")) {
+          if (strchr (option, '=') == NO_TEXT) {
             FORWARD (i);
             if (i != NO_OPTION_LIST) {
               if (strcmp (STR (i), "=") == 0) {
@@ -723,13 +729,13 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           }
         }
 // ERROR-CHECK generates (some) runtime checks for O2, O3, Ofast.
-        else if (eq (p, "ERRor-check")) {
+        else if (eq (option, "ERRor-check")) {
           OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
         }
 // EXECUTE and PRINT execute their argument as Algol 68 text.
-        else if (eq (p, "Execute") || eq (p, "X") || eq (p, "Print")) {
+        else if (eq (option, "Execute") || eq (option, "X") || eq (option, "Print")) {
           if (cmd_line == A68G_FALSE) {
-            option_error (start_l, start_c, ERROR_COMMAND_LINE);
+            option_error (start_l, full_option, ERROR_COMMAND_LINE);
           } else if ((FORWARD (i)) != NO_OPTION_LIST) {
             BOOL_T error = A68G_FALSE;
             if (strcmp (STR (i), "=") == 0) {
@@ -743,7 +749,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE *f = a68g_fopen (name, "w", new_name);
               ABEND (f == NO_FILE, ERROR_ACTION, NO_TEXT);
               errno = s_errno;
-              if (eq (p, "Execute") || eq (p, "X")) {
+              if (eq (option, "Execute") || eq (option, "X")) {
                 fprintf (f, "(%s)\n", STR (i));
               } else {
                 fprintf (f, "(print (((%s), new line)))\n", STR (i));
@@ -751,18 +757,18 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               ASSERT (fclose (f) == 0);
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (new_name, NO_TEXT);
             } else {
-              option_error (start_l, start_c, ERROR_MISSING_STUFF);
+              option_error (start_l, full_option, ERROR_MISSING_STUFF);
             }
           } else {
-            option_error (start_l, start_c, ERROR_MISSING_STUFF);
+            option_error (start_l, full_option, ERROR_MISSING_STUFF);
           }
         }
 // EXIT stops option processing.
-        else if (eq (p, "EXIT")) {
+        else if (eq (option, "EXIT")) {
           siga = A68G_FALSE;
         }
 // EXTENSIVE set of options for an extensive listing.
-        else if (eq (p, "EXTensive")) {
+        else if (eq (option, "EXTensive")) {
           OPTION_SOURCE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_OBJECT_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_TREE_LISTING (&A68G_JOB) = A68G_TRUE;
@@ -774,7 +780,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           OPTION_NODEMASK (&A68G_JOB) |= (CROSS_REFERENCE_MASK | TREE_MASK | CODE_MASK | SOURCE_MASK);
         }
 // FILE accepts its argument as filename.
-        else if (eq (p, "File") && cmd_line) {
+        else if (eq (option, "File") && cmd_line) {
           FORWARD (i);
           if (i != NO_OPTION_LIST && strcmp (STR (i), "=") == 0) {
             FORWARD (i);
@@ -784,59 +790,59 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
               name_set = A68G_TRUE;
             } else {
-              option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
+              option_error (start_l, full_option, ERROR_MULTIPLE_SOURCE_FILES);
             }
           } else {
-            option_error (start_l, start_c, ERROR_MISSING_STUFF);
+            option_error (start_l, full_option, ERROR_MISSING_STUFF);
           }
         }
 // FOLD performs constant folding in basic lay-out formatting..
-        else if (eq (p, "FOLD")) {
+        else if (eq (option, "FOLD")) {
           OPTION_INDENT (&A68G_JOB) = A68G_TRUE;
           OPTION_FOLD (&A68G_JOB) = A68G_TRUE;
           OPTION_CHECK_ONLY (&A68G_JOB) = A68G_TRUE;
         }
 // KEEP switches off/on object file deletion.
-        else if (eq (p, "KEEP")) {
+        else if (eq (option, "KEEP")) {
           OPTION_KEEP (&A68G_JOB) = A68G_TRUE;
-        } else if (eq (p, "NOKEEP") || eq (p, "NO-KEEP")) {
+        } else if (eq (option, "NOKEEP") || eq (option, "NO-KEEP")) {
           OPTION_KEEP (&A68G_JOB) = A68G_FALSE;
         }
 // INCLUDE preprocessor item stops option processing.
-        else if (eq (p, "INCLUDE") || eq (p, "READ")) {
+        else if (eq (option, "INCLUDE") || eq (option, "READ")) {
           siga = A68G_FALSE;
         }
 // LICENSE states the license
-        else if (eq (p, "LICense")) {
+        else if (eq (option, "LICense")) {
           OPTION_LICENSE (&A68G_JOB) = A68G_TRUE;
         }
 // LISTING set of options for a default listing.
-        else if (eq (p, "Listing")) {
+        else if (eq (option, "Listing")) {
           OPTION_SOURCE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_CROSS_REFERENCE (&A68G_JOB) = A68G_TRUE;
           OPTION_STATISTICS_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_NODEMASK (&A68G_JOB) |= (SOURCE_MASK | CROSS_REFERENCE_MASK);
         }
 // MODULAR-ARITHMETIC. 
-        else if (eq (p, "MODular-arithmetic")) {
+        else if (eq (option, "MODular-arithmetic")) {
         // Make A68G permissive towards BITS values corresponding to negative INT values that RR forbids.
           OPTION_NODEMASK (&A68G_JOB) |= MODULAR_MASK;
-        } else if (eq (p, "NOMODular-arithmetic") || eq (p, "NO-MODular-arithmetic")) {
+        } else if (eq (option, "NOMODular-arithmetic") || eq (option, "NO-MODular-arithmetic")) {
           OPTION_NODEMASK (&A68G_JOB) &= ~MODULAR_MASK;
         }
 // MOIDS prints an overview of moids used in the program.
-        else if (eq (p, "MOIDS")) {
+        else if (eq (option, "MOIDS")) {
           OPTION_MOID_LISTING (&A68G_JOB) = A68G_TRUE;
         }
 // MONITOR or DEBUG invokes the debugger at runtime errors.
-        else if (eq (p, "MONitor") || eq (p, "DEBUG")) {
+        else if (eq (option, "MONitor") || eq (option, "DEBUG")) {
           OPTION_DEBUG (&A68G_JOB) = A68G_TRUE;
         }
 // NEED or LIBrary require the argument as environ.
-        else if (eq (p, "NEED") || eq (p, "LIBrary")) {
+        else if (eq (option, "NEED") || eq (option, "LIBrary")) {
           FORWARD (i);
           if (i == NO_OPTION_LIST) {
-            option_error (start_l, start_c, ERROR_MISSING_STUFF);
+            option_error (start_l, full_option, ERROR_MISSING_STUFF);
           } else {
             OPTION_LIST_T *save = i; BOOL_T good = A68G_FALSE;
             do {
@@ -851,85 +857,117 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           }
         }
 // NOTICES switches notices on/off.
-        else if (eq (p, "Notices")) {
+        else if (eq (option, "Notices")) {
           OPTION_NO_NOTICES (&A68G_JOB) = A68G_FALSE;
-        } else if (eq (p, "NONotices")) {
+        } else if (eq (option, "NONotices")) {
           OPTION_NO_NOTICES (&A68G_JOB) = A68G_TRUE;
-        } else if (eq (p, "NO-NOTICEs")) {
+        } else if (eq (option, "NO-NOTICEs")) {
           OPTION_NO_NOTICES (&A68G_JOB) = A68G_TRUE;
         }
  // NOGC is for a68g development purposes.
-        else if (eq (p, "NOGC") || eq (p, "NO-GC")) {
+        else if (eq (option, "NOGC") || eq (option, "NO-GC")) {
           OPTION_CONSERVATIVE_GC (&A68G_JOB) = A68G_GC_HALT;
         }
 // OBJECT prints object lines.
-        else if (eq (p, "OBJECT")) {
+        else if (eq (option, "OBJECT")) {
           OPTION_OBJECT_LISTING (&A68G_JOB) = A68G_TRUE;
-        } else if (eq (p, "NOOBJECT") || eq (p, "NO-OBJECT")) {
+        } else if (eq (option, "NOOBJECT") || eq (option, "NO-OBJECT")) {
           OPTION_OBJECT_LISTING (&A68G_JOB) = A68G_FALSE;
         }
 // OPTIMISE switches on/off optimisation.
-        else if (eq (p, "OPTimise") || eq (p, "OPTimize")) {
-          OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
-          OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_1;
-        } else if (eq (p, "NOOptimize") || eq (p, "NO-Optimize")) {
-          OPTION_OPT_LEVEL (&A68G_JOB) = NO_OPTIMISE;
-        } else if (eq (p, "O0")) {
-          OPTION_OPT_LEVEL (&A68G_JOB) = NO_OPTIMISE;
-        } else if (eq (p, "OG")) {
-          OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
-          OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_0;
-        } else if (eq (p, "O") || eq (p, "O1")) {
-          OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
-          OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_1;
-        } else if (eq (p, "O2")) {
-          OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_FALSE;
-          OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_2;
-        } else if (eq (p, "O3")) {
-          OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_FALSE;
-          OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_3;
-        } else if (eq (p, "Ofast")) {
-          OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_FALSE;
-          OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_FAST;
+        else if (eq (option, "OPTimise") || eq (option, "OPTimize")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
+            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_1;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "NOOptimize") || eq (option, "NO-Optimize")) {
+          #if defined (BUILD_UNIX)
+            OPTION_OPT_LEVEL (&A68G_JOB) = NO_OPTIMISE;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "O0")) {
+          #if defined (BUILD_UNIX)
+            OPTION_OPT_LEVEL (&A68G_JOB) = NO_OPTIMISE;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "OG")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
+            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_0;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "O") || eq (option, "O1")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_TRUE;
+            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_1;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "O2")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_FALSE;
+            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_2;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "O3")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_FALSE;
+            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_3;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        } else if (eq (option, "Ofast")) {
+          #if defined (BUILD_UNIX)
+            OPTION_COMPILE_CHECK (&A68G_JOB) = A68G_FALSE;
+            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_FAST;
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
         }
 // PEDANTIC switches portcheck and warnings on.
-        else if (eq (p, "PEDANTIC")) {
+        else if (eq (option, "PEDANTIC")) {
           OPTION_PORTCHECK (&A68G_JOB) = A68G_TRUE;
           OPTION_NO_NOTICES (&A68G_JOB) = A68G_FALSE;
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_FALSE;
         }
 // PORTCHECK switches portcheck on/off.
-        else if (eq (p, "PORTcheck")) {
+        else if (eq (option, "PORTcheck")) {
           OPTION_PORTCHECK (&A68G_JOB) = A68G_TRUE;
         }
-        else if (eq (p, "NOPORTcheck")) {
+        else if (eq (option, "NOPORTcheck")) {
           OPTION_PORTCHECK (&A68G_JOB) = A68G_FALSE;
-        } else if (eq (p, "NO-PORTcheck")) {
+        } else if (eq (option, "NO-PORTcheck")) {
           OPTION_PORTCHECK (&A68G_JOB) = A68G_FALSE;
         }
 // PRAGMATS switches pragmat processing on/off.
-        else if (eq (p, "PRagmats")) {
+        else if (eq (option, "PRagmats")) {
           OPTION_PRAGMAT_SEMA (&A68G_JOB) = A68G_TRUE;
-        } else if (eq (p, "NOPRagmats") || eq (p, "NO-PRagmats")) {
+        } else if (eq (option, "NOPRagmats") || eq (option, "NO-PRagmats")) {
           OPTION_PRAGMAT_SEMA (&A68G_JOB) = A68G_FALSE;
         }
 // PRECISION sets LONG LONG precision.
-        else if (eq (p, "PRECision")) {
+        else if (eq (option, "PRECision")) {
           BOOL_T error = A68G_FALSE;
-          INT_T N = fetch_integral (p, &i, &error, A68G_MAX_INT);
+          INT_T N = fetch_integral (option, &i, &error, A68G_MAX_INT);
           int k = width_to_mp_digits (N);
           if (k <= 0 || error || errno > 0) {
-            option_error (start_l, start_c, ERROR_INVALID_VALUE);
+            option_error (start_l, full_option, ERROR_INVALID_VALUE);
           } else if (long_mp_digits () > 0 && long_mp_digits () != k) {
-            option_error (start_l, start_c, ERROR_PRECISION_SET);
+            option_error (start_l, full_option, ERROR_PRECISION_SET);
           } else if (k > mp_digits ()) {
             set_long_mp_digits (k);
           } else {
-            option_error (start_l, start_c, ERROR_PRECISION_TOO_LOW);
+            option_error (start_l, full_option, ERROR_PRECISION_TOO_LOW);
           }
         }
 // PRELUDELISTING cross references preludes.
-        else if (eq (p, "PRELUDElisting") || eq (p, "PRELUDE-listing")) {
+        else if (eq (option, "PRELUDElisting") || eq (option, "PRELUDE-listing")) {
           OPTION_SOURCE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_CROSS_REFERENCE (&A68G_JOB) = A68G_TRUE;
           OPTION_STATISTICS_LISTING (&A68G_JOB) = A68G_TRUE;
@@ -937,28 +975,28 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           OPTION_STANDARD_PRELUDE_LISTING (&A68G_JOB) = A68G_TRUE;
         }
 // PREPROCESSOR stops option processing.
-        else if (eq (p, "PREPROCESSOR") || eq (p, "NOPREPROCESSOR")) {
+        else if (eq (option, "PREPROCESSOR") || eq (option, "NOPREPROCESSOR") || eq (option, "NO-PREPROCESSOR")) {
           siga = A68G_FALSE;
         } 
 // PRETTY and INDENT perform basic pretty printing.
-        else if (eq (p, "PRETty-print") || eq (p, "INDENT")) {
+        else if (eq (option, "PRETty-print") || eq (option, "INDENT")) {
           OPTION_PRETTY (&A68G_JOB) = A68G_TRUE;
           OPTION_CHECK_ONLY (&A68G_JOB) = A68G_TRUE;
         }
 // QUIET switches all warnings and notices off.
-        else if (eq (p, "Quiet")) {
+        else if (eq (option, "Quiet")) {
           OPTION_QUIET (&A68G_JOB) = A68G_TRUE;
           OPTION_NO_NOTICES (&A68G_JOB) = A68G_TRUE;
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
         }
 // QUOTESTROPPING sets stropping to quote stropping.
-        else if (eq (p, "QUOTEstropping")) {
+        else if (eq (option, "QUOTEstropping")) {
           OPTION_STROPPING (&A68G_JOB) = QUOTE_STROPPING;
-        } else if (eq (p, "QUOTE-stropping")) {
+        } else if (eq (option, "QUOTE-stropping")) {
           OPTION_STROPPING (&A68G_JOB) = QUOTE_STROPPING;
         }
 // REGRESSION sets preferences when running the test suite - undocumented option.
-        else if (eq (p, "REGRession")) {
+        else if (eq (option, "REGRession")) {
           OPTION_NO_NOTICES (&A68G_JOB) = A68G_FALSE;
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_FALSE;
           OPTION_PORTCHECK (&A68G_JOB) = A68G_TRUE;
@@ -968,56 +1006,72 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           A68G (term_width) = MAX_TERM_WIDTH;
         }
 // REDUCTIONS gives parser reductions.
-        else if (eq (p, "REDuctions")) {
+        else if (eq (option, "REDuctions")) {
           OPTION_REDUCTIONS (&A68G_JOB) = A68G_TRUE;
         }
+// RESTART restarts system calls at TIME-LIMIT check.
+        else if (eq (option, "RESTART") || eq (option, "NORESTART") || eq (option, "NO-RESTART")) {
+          #if defined (BUILD_UNIX)
+            if (eq (option, "RESTART")) {
+              OPTION_RESTART (&A68G_JOB) = A68G_TRUE;
+            } else if (eq (option, "NORESTART") || eq (option, "NO-RESTART")) {
+              OPTION_RESTART (&A68G_JOB) = A68G_FALSE;
+            }
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
+        }
 // RERUN re-uses an existing .so file.
-        else if (eq (p, "RERUN")) {
-          OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
-          OPTION_RERUN (&A68G_JOB) = A68G_TRUE;
-          if (OPTION_OPT_LEVEL (&A68G_JOB) < OPTIMISE_1) {
-            OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_1;
-          }
+        else if (eq (option, "RERUN")) {
+          #if defined (BUILD_LINUX)
+            OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
+            OPTION_RERUN (&A68G_JOB) = A68G_TRUE;
+            if (OPTION_OPT_LEVEL (&A68G_JOB) < OPTIMISE_1) {
+              OPTION_OPT_LEVEL (&A68G_JOB) = OPTIMISE_1;
+            }
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
         }
 // RUN overrides NORUN.
-        else if (eq (p, "RUN")) {
+        else if (eq (option, "RUN")) {
           OPTION_RUN (&A68G_JOB) = A68G_TRUE;
         }
 // RUN-QUOTE-SCRIPT runs a compiled .sh script.
-        else if (eq (p, "RUN-QUOTE-SCRIPT")) {
-          #if defined (BUILD_LINUX) || defined (BUILD_BSD)
+        else if (eq (option, "RUN-QUOTE-SCRIPT")) {
+          #if defined (BUILD_UNIX)
             FORWARD (i);
             if (i != NO_OPTION_LIST) {
               if (!name_set) {
                 FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
                 name_set = A68G_TRUE;
               } else {
-                option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
+                option_error (start_l, full_option, ERROR_MULTIPLE_SOURCE_FILES);
               }
             } else {
-              option_error (start_l, start_c, ERROR_MISSING_STUFF);
+              option_error (start_l, full_option, ERROR_MISSING_STUFF);
             }
             skip = A68G_TRUE;
             OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_TRUE;
             OPTION_STROPPING (&A68G_JOB) = QUOTE_STROPPING;
             OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
           #else
-            option_error (start_l, start_c, ERROR_PLATFORM);
+            option_error (start_l, full_option, ERROR_PLATFORM);
           #endif
         }
 // RUN-SCRIPT runs a compiled .sh script.
-        else if (eq (p, "RUN-SCRIPT")) {
-          #if defined (BUILD_LINUX) || defined (BUILD_BSD)
+        else if (eq (option, "RUN-SCRIPT")) {
+          #if defined (BUILD_UNIX)
             FORWARD (i);
             if (i != NO_OPTION_LIST) {
               if (!name_set) {
                 FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
                 name_set = A68G_TRUE;
               } else {
-                option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
+                option_error (start_l, full_option, ERROR_MULTIPLE_SOURCE_FILES);
               }
             } else {
-              option_error (start_l, start_c, ERROR_MISSING_STUFF);
+              option_error (start_l, full_option, ERROR_MISSING_STUFF);
             }
             skip = A68G_TRUE;
             OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_TRUE;
@@ -1025,15 +1079,15 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
             OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
             OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
           #else
-            option_error (start_l, start_c, ERROR_PLATFORM);
+            option_error (start_l, full_option, ERROR_PLATFORM);
           #endif
         }
 // SAFEGC is for a68g development purposes.
-        else if (eq (p, "SAFEGC") || eq (p, "SAFE-GC")) {
+        else if (eq (option, "SAFEGC") || eq (option, "SAFE-GC")) {
           OPTION_CONSERVATIVE_GC (&A68G_JOB) = A68G_GC_SAFE;
         } 
 // SCRIPT takes next argument as filename.
-        else if (eq (p, "Script") && cmd_line) {
+        else if (eq (option, "Script") && cmd_line) {
         // Further options on the command line are not processed, but stored.
           FORWARD (i);
           if (i != NO_OPTION_LIST) {
@@ -1041,141 +1095,143 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
               name_set = A68G_TRUE;
             } else {
-              option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
+              option_error (start_l, full_option, ERROR_MULTIPLE_SOURCE_FILES);
             }
           } else {
-            option_error (start_l, start_c, ERROR_MISSING_STUFF);
+            option_error (start_l, full_option, ERROR_MISSING_STUFF);
           }
           skip = A68G_TRUE;
         }
 // STATISTICS prints process statistics.
-        else if (eq (p, "STatistics")) {
+        else if (eq (option, "STatistics")) {
           OPTION_STATISTICS_LISTING (&A68G_JOB) = A68G_TRUE;
         }
 // SOURCE prints source lines.
-        else if (eq (p, "SOURCE")) {
+        else if (eq (option, "SOURCE")) {
           OPTION_SOURCE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_NODEMASK (&A68G_JOB) |= SOURCE_MASK;
-        } else if (eq (p, "NOSOURCE") || eq (p, "NO-SOURCE")) {
+        } else if (eq (option, "NOSOURCE") || eq (option, "NO-SOURCE")) {
           OPTION_NODEMASK (&A68G_JOB) &= ~SOURCE_MASK;
         }
 // STORAGE, HEAP, HANDLES, STACK, FRAME and OVERHEAD set core allocation.
-        else if (eq (p, "STOrage") || eq (p, "HEAP") || eq (p, "HANDLES") || eq (p, "STACK") || eq (p, "FRAME") || eq (p, "OVERHEAD")) {
+        else if (eq (option, "STOrage") || eq (option, "HEAP") || eq (option, "HANDLES") || eq (option, "STACK") || eq (option, "FRAME") || eq (option, "OVERHEAD")) {
           BOOL_T error = A68G_FALSE;
-          INT_T k = fetch_integral (p, &i, &error, MAX_MEM_SIZE);
+          INT_T k = fetch_integral (option, &i, &error, MAX_MEM_SIZE);
           if (error || errno > 0) {
-            option_error (start_l, start_c, ERROR_INVALID_VALUE);
+            option_error (start_l, full_option, ERROR_INVALID_VALUE);
           } else if (k > 0) {
-            if (eq (p, "STOrage")) {
-              default_mem_sizes (k, start_l, start_c);
+            if (eq (option, "STOrage")) {
+              default_mem_sizes (k, start_l, full_option);
             } else {
               if (k < A68G (storage_overhead)) {
-                option_error (start_l, start_c, ERROR_INVALID_VALUE);
+                option_error (start_l, full_option, ERROR_INVALID_VALUE);
                 k = A68G (storage_overhead);
               }
               storage_limit (k + A68G (storage_overhead));
-              if (eq (p, "HEAP")) {
+              if (eq (option, "HEAP")) {
                 A68G (heap_size) = k;
-              } else if (eq (p, "HANDLES")) {
+              } else if (eq (option, "HANDLES")) {
                 A68G (handle_pool_size) = k;
-              } else if (eq (p, "STACK")) {
+              } else if (eq (option, "STACK")) {
                 A68G (expr_stack_size) = k;
-              } else if (eq (p, "FRAME")) {
+              } else if (eq (option, "FRAME")) {
                 A68G (frame_stack_size) = k;
-              } else if (eq (p, "OVERHEAD")) {
+              } else if (eq (option, "OVERHEAD")) {
                 A68G (storage_overhead) = k;
               }
             }
           }
         }
 // STRICT ignores A68G extensions to A68 syntax.
-        else if (eq (p, "STRict")) {
+        else if (eq (option, "STRict")) {
           OPTION_STRICT (&A68G_JOB) = A68G_TRUE;
           OPTION_PORTCHECK (&A68G_JOB) = A68G_TRUE;
         }
 // TECH prints out some tech stuff.
-        else if (eq (p, "TECHnicalities")) {
+        else if (eq (option, "TECHnicalities")) {
           tech_stuff ();
         }
 // TIMELIMIT lets the interpreter stop after so-many seconds.
-        else if (eq (p, "TImelimit") || eq (p, "TIME-Limit")) {
-          BOOL_T error = A68G_FALSE;
-          INT_T k = fetch_integral (p, &i, &error, A68G_MAX_INT);
-          if (error || errno > 0) {
-            option_error (start_l, start_c, ERROR_INVALID_VALUE);
-          } else if (k < 1) {
-            option_error (start_l, start_c, ERROR_INVALID_VALUE);
-          } else {
-            OPTION_TIME_LIMIT (&A68G_JOB) = k;
-          }
+        else if (eq (option, "TImelimit") || eq (option, "TIME-Limit")) {
+          #if defined (BUILD_LINUX)
+            BOOL_T error = A68G_FALSE;
+            INT_T k = fetch_integral (option, &i, &error, A68G_MAX_INT);
+            if (error || errno > 0) {
+              option_error (start_l, full_option, ERROR_INVALID_VALUE);
+            } else if (k < 1) {
+              option_error (start_l, full_option, ERROR_INVALID_VALUE);
+            } else {
+              OPTION_TIME_LIMIT (&A68G_JOB) = k;
+            }
+          #else
+            option_error (start_l, full_option, ERROR_PLATFORM);
+          #endif
         }
 // TREE switches on/off printing of the syntax tree. This gets bulky!.
-        else if (eq (p, "TREE")) {
+        else if (eq (option, "TREE")) {
           OPTION_SOURCE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_TREE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_NODEMASK (&A68G_JOB) |= (TREE_MASK | SOURCE_MASK);
-        } else if (eq (p, "NOTREE") || eq (p, "NO-TREE")) {
+        } else if (eq (option, "NOTREE") || eq (option, "NO-TREE")) {
           OPTION_NODEMASK (&A68G_JOB) ^= (TREE_MASK | SOURCE_MASK);
         }
 // TRACE switches on/off tracing of the running program.
-        else if (eq (p, "TRace")) {
+        else if (eq (option, "TRace")) {
           OPTION_TRACE (&A68G_JOB) = A68G_TRUE;
           OPTION_NODEMASK (&A68G_JOB) |= BREAKPOINT_TRACE_MASK;
-        } else if (eq (p, "NOTRace") || eq (p, "NO-TRace")) {
+        } else if (eq (option, "NOTRace") || eq (option, "NO-TRace")) {
           OPTION_NODEMASK (&A68G_JOB) &= ~BREAKPOINT_TRACE_MASK;
         }
-// TTY send listing to standout. Remnant from my mainframe past.
-        else if (eq (p, "TTY")) {
-          OPTION_CROSS_REFERENCE (&A68G_JOB) = A68G_TRUE;
-          OPTION_STATISTICS_LISTING (&A68G_JOB) = A68G_TRUE;
-          OPTION_NODEMASK (&A68G_JOB) |= (SOURCE_MASK | CROSS_REFERENCE_MASK);
-        }
 // UNUSED indicates unused tags.
-        else if (eq (p, "UNUSED")) {
+        else if (eq (option, "UNUSED")) {
           OPTION_UNUSED (&A68G_JOB) = A68G_TRUE;
         }
 // UPPERSTROPPING sets stropping to upper stropping, which is nowadays the expected default.
-        else if (eq (p, "UPPERstropping") || eq (p, "UPPER-stropping")) {
+        else if (eq (option, "UPPERstropping") || eq (option, "UPPER-stropping")) {
           OPTION_STROPPING (&A68G_JOB) = UPPER_STROPPING;
         }
 // VERBOSE in case you want to know what Algol68G is doing.
-        else if (eq (p, "VERBose")) {
+        else if (eq (option, "VERBose")) {
           OPTION_VERBOSE (&A68G_JOB) = A68G_TRUE;
         }
 // VERIFY checks that argument is current a68g version number.
-        else if (eq (p, "VERIFY")) {
+        else if (eq (option, "VERIFY")) {
           FORWARD (i);
           if (i != NO_OPTION_LIST && strcmp (STR (i), "=") == 0) {
             FORWARD (i);
           }
           if (i != NO_OPTION_LIST) {
-            ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s verification \"%s\" does not match script verification \"%s\"", A68G (a68g_cmd_name), PACKAGE_STRING, STR (i)) >= 0);
-            ABEND (strcmp (PACKAGE_STRING, STR (i)) != 0, new_string (A68G (output_line), NO_TEXT), "outdated script");
+            #if defined (BUILD_LINUX)
+              ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s verification \"%s\" does not match script verification \"%s\"", A68G (a68g_cmd_name), PACKAGE_STRING, STR (i)) >= 0);
+              ABEND (strcmp (PACKAGE_STRING, STR (i)) != 0, new_string (A68G (output_line), NO_TEXT), "outdated script");
+            #else
+              option_error (start_l, full_option, ERROR_PLATFORM);
+            #endif
           } else {
-            option_error (start_l, start_c, ERROR_MISSING_STUFF);
+            option_error (start_l, full_option, ERROR_MISSING_STUFF);
           }
         }
 // VERSION lists the current version at an appropriate time in the future.
-        else if (eq (p, "Version")) {
+        else if (eq (option, "Version")) {
           OPTION_VERSION (&A68G_JOB) = A68G_TRUE;
         } 
 // WARNINGS switches unsuppressible warnings on/off.
-        else if (eq (p, "Warnings")) {
+        else if (eq (option, "Warnings")) {
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_FALSE;
-        } else if (eq (p, "NOWarnings") || eq (p, "NO-Warnings")) {
+        } else if (eq (option, "NOWarnings") || eq (option, "NO-Warnings")) {
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
         }
 // XREF switch cross referencing on/off.
-        else if (eq (p, "XREF")) {
+        else if (eq (option, "XREF")) {
           OPTION_SOURCE_LISTING (&A68G_JOB) = A68G_TRUE;
           OPTION_CROSS_REFERENCE (&A68G_JOB) = A68G_TRUE;
           OPTION_NODEMASK (&A68G_JOB) |= (CROSS_REFERENCE_MASK | SOURCE_MASK);
-        } else if (eq (p, "NOXREF") || eq (p, "NO-Xref")) {
+        } else if (eq (option, "NOXREF") || eq (option, "NO-Xref")) {
           OPTION_NODEMASK (&A68G_JOB) &= ~(CROSS_REFERENCE_MASK | SOURCE_MASK);
         }
 // Unrecognised.
         else {
-          option_error (start_l, start_c, ERROR_UNRECOGNISED_OPTION);
+          option_error (start_l, full_option, ERROR_UNRECOGNISED_OPTION);
         }
       }
 // Process next item, if present.
