@@ -234,6 +234,33 @@ void genie_widen_double_int_to_double (NODE_T * p)
   VALUE (z) = double_int_to_double (p, VALUE (z));
 }
 
+void standardize_double (DOUBLE_T * y, int before, int after, int *p)
+{
+// PROC standardize = (REF REAL y, INT before, after, REF INT p) VOID:
+// BEGIN REAL g = 10.0 ^ before, REAL h := g * .1;
+  DOUBLE_T g = ten_up_double (before);
+  DOUBLE_T h = g * 0.1q;
+//       WHILE y >= g DO y *:= .1; p +:= 1 OD;
+  while (*y >= g) {
+    *y *= 0.1q;
+    (*p)++;
+  }
+//       (y /= 0.0 | WHILE y < h DO y *:= 10.0; p -:= 1 OD);
+  if (*y != 0.0q) {
+    while (*y < h) {
+      *y *= 10.0q;
+      (*p)--;
+    }
+  }
+//       (y + .5 * .1 ^ after >= g | y := h; p +:= 1)
+  DOUBLE_T f = ten_up_double (-after);
+  if (*y + 0.5q * f >= g) {
+    *y = h;
+    (*p)++;
+  }
+// END;
+}
+
 //! @brief OP LENG = (REAL) LONG REAL
 
 DOUBLE_NUM_T dble_double (NODE_T * p, REAL_T z)
@@ -242,8 +269,9 @@ DOUBLE_NUM_T dble_double (NODE_T * p, REAL_T z)
   BOOL_T nega = (z < 0.0);
   REAL_T u = fabs (z);
   int expo = 0;
-  standardise (&u, 1, A68G_REAL_DIG, &expo);
-  u *= ten_up (A68G_REAL_DIG);
+  DOUBLE_T v = (DOUBLE_T) u;
+  standardize_double (&v, 1, A68G_REAL_DIG, &expo);
+  u = ((REAL_T) v) * ten_up (A68G_REAL_DIG);
   expo -= A68G_REAL_DIG;
   DOUBLE_NUM_T w;
   set_lw (w, (INT_T) u);
@@ -340,7 +368,7 @@ DOUBLE_NUM_T mp_to_double_int (NODE_T * p, MP_T * z, int digs)
 
 //! @brief Convert real to multi-precison number.
 
-MP_T *double_to_mp (NODE_T * p, MP_T * z, DOUBLE_T x, int digs)
+MP_T *double_to_mp (NODE_T * p, MP_T * z, DOUBLE_T x, int prec, BOOL_T round, int digs)
 {
   SET_MP_ZERO (z, digs);
   if (x == 0.0q) {
@@ -361,12 +389,18 @@ MP_T *double_to_mp (NODE_T * p, MP_T * z, DOUBLE_T x, int digs)
     expo++;
   }
 // Transport digits of x to the mantissa of z.
-  int j = 1, sum = 0, weight = (MP_RADIX / 10);
-  for (int k = 0; a != 0.0q && j <= digs && k < A68G_DOUBLE_MAN; k++) {
+  int j = 1, sum = 0, weight = (MP_RADIX / 10), num = 0, lim = MIN (prec, A68G_DOUBLE_DIG), nines = 0;
+  for (int k = 0; k < lim && j <= digs && a != 0.0q; k++) {
     DOUBLE_T u = a * 10.0q;
     DOUBLE_T v = floor_double (u);
     a = u - v;
-    sum += weight * (int) v;
+    num = (int) v;
+    if (num == 9) {
+      nines++;
+    } else {
+      nines = 0;
+    }
+    sum += weight * num;
     weight /= 10;
     if (weight < 1) {
       MP_DIGIT (z, j++) = (MP_T) sum;
@@ -378,8 +412,23 @@ MP_T *double_to_mp (NODE_T * p, MP_T * z, DOUBLE_T x, int digs)
   if (j <= digs) {
     MP_DIGIT (z, j) = (MP_T) sum;
   }
+//
+  INT_T shift = 1 + expo - prec;
   (void) align_mp (z, &expo, digs);
   MP_EXPONENT (z) = (MP_T) expo;
+// Round when requested by caller.
+// Heuristic - round when at least half of the digits are trailing '9's.
+// This avoids some surprises in REAL transput:
+//   "fixed (1.15, 0, 1)" would produce "1.1",
+//   "fixed (1.25, 0, 1)" would produce "1.3".
+  if (round && nines >= prec / 2) {
+    ADDR_T pop_sp = A68G_SP;
+    MP_T *t = nil_mp (p, digs);
+    ten_up_mp (p, t, shift, digs);
+    add_mp (p, z, z, t, digs);
+    A68G_SP = pop_sp;
+  }
+//
   MP_DIGIT (z, 1) *= sign_x;
   check_mp_exp (p, z);
   return z;
@@ -436,7 +485,7 @@ void genie_lengthen_double_to_mp (NODE_T * p)
   A68G_LONG_REAL x;
   POP_OBJECT (p, &x, A68G_LONG_REAL);
   MP_T *z = nil_mp (p, digs);
-  (void) double_to_mp (p, z, VALUE (&x).f, digs);
+  (void) double_to_mp (p, z, VALUE (&x).f, A68G_DOUBLE_DIG, A68G_FALSE, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
 }
 
@@ -1075,7 +1124,7 @@ void genie_double_bits_pack (NODE_T * p)
   CHECK_REF (p, z, M_ROW_BOOL);
   A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &z);
-  int size = ROW_SIZE (tup);
+  size_t size = ROW_SIZE (tup);
   PRELUDE_ERROR (size < 0 || size > A68G_LONG_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_ROW_BOOL);
   DOUBLE_NUM_T w;
   set_lw (w, 0x0);
@@ -1387,10 +1436,10 @@ void genie_lengthen_double_compl_to_long_mp_complex (NODE_T * p)
   POP_OBJECT (p, &im, A68G_LONG_REAL);
   POP_OBJECT (p, &re, A68G_LONG_REAL);
   MP_T *z = nil_mp (p, digs);
-  (void) double_to_mp (p, z, VALUE (&re).f, digs);
+  (void) double_to_mp (p, z, VALUE (&re).f, A68G_DOUBLE_DIG, A68G_FALSE, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   z = nil_mp (p, digs);
-  (void) double_to_mp (p, z, VALUE (&im).f, digs);
+  (void) double_to_mp (p, z, VALUE (&im).f, A68G_DOUBLE_DIG, A68G_FALSE, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
 }
 
@@ -1995,4 +2044,25 @@ void genie_minus_infinity_double (NODE_T * p)
   PUSH_VALUE (p, dble (a68g_neginf_double ()), A68G_LONG_REAL);
 }
 
+// Range check.
+
+BOOL_T a68g_finite_double (REAL_T x)
+{
+  return !isinfq (x) && !isnanq (x);
+}
+
+// Range check.
+
+BOOL_T a68g_isnan_double (REAL_T x)
+{
+  return isnanq (x);
+}
+
+// Range check.
+
+BOOL_T a68g_isinf_double (REAL_T x)
+{
+  return isinfq (x);
+}
+
 #endif
