@@ -111,27 +111,27 @@ PROP_T genie_widen (NODE_T * p)
     make_constant_widening (p, M_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_INT, M_LONG_INT)) {
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_int_to_double_int (p);
-#else
-    genie_lengthen_int_to_mp (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_int_to_double_int (p);
+    #else
+      genie_lengthen_int_to_mp (p);
+    #endif
     make_constant_widening (p, M_LONG_INT, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_INT, M_LONG_LONG_INT)) {
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_double_int_to_mp (p);
-#else
-    genie_lengthen_mp_to_long_mp (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_double_int_to_mp (p);
+    #else
+      genie_lengthen_mp_to_long_mp (p);
+    #endif
     make_constant_widening (p, M_LONG_LONG_INT, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_INT, M_LONG_REAL)) {
-#if (A68G_LEVEL >= 3)
-    (void) genie_widen_double_int_to_double (p);
-#else
+    #if (A68G_LEVEL >= 3)
+      (void) genie_widen_double_int_to_double (p);
+    #else
 // 1-1 mapping.
-    GENIE_UNIT (SUB (p));
-#endif
+      GENIE_UNIT (SUB (p));
+    #endif
     make_constant_widening (p, M_LONG_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_LONG_INT, M_LONG_LONG_REAL)) {
     GENIE_UNIT (SUB (p));
@@ -141,35 +141,35 @@ PROP_T genie_widen (NODE_T * p)
 // REAL widenings.
   else if (COERCE_FROM_TO (p, M_REAL, M_LONG_REAL)) {
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_real_to_double (p);
-#else
-    genie_lengthen_real_to_mp (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_real_to_double (p);
+    #else
+      genie_lengthen_real_to_mp (p);
+    #endif
     make_constant_widening (p, M_LONG_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_REAL, M_LONG_LONG_REAL)) {
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_double_to_mp (p);
-#else
-    genie_lengthen_mp_to_long_mp (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_double_to_mp (p);
+    #else
+      genie_lengthen_mp_to_long_mp (p);
+    #endif
     make_constant_widening (p, M_LONG_LONG_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_REAL, M_COMPLEX)) {
     GENIE_UNIT (SUB (p));
     PUSH_VALUE (p, 0.0, A68G_REAL);
     make_constant_widening (p, M_COMPLEX, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_REAL, M_LONG_COMPLEX)) {
-#if (A68G_LEVEL >= 3)
-    DOUBLE_NUM_T z;
-    z.f = 0.0q;
-    GENIE_UNIT (SUB (p));
-    PUSH_VALUE (p, z, A68G_LONG_REAL);
-#else
-    GENIE_UNIT (SUB (p));
-    (void) nil_mp (p, DIGITS (M_LONG_REAL));
-    make_constant_widening (p, M_LONG_COMPLEX, &self);
-#endif
+    #if (A68G_LEVEL >= 3)
+      DOUBLE_NUM_T z;
+      z.f = 0.0q;
+      GENIE_UNIT (SUB (p));
+      PUSH_VALUE (p, z, A68G_LONG_REAL);
+    #else
+      GENIE_UNIT (SUB (p));
+      (void) nil_mp (p, DIGITS (M_LONG_REAL));
+      make_constant_widening (p, M_LONG_COMPLEX, &self);
+    #endif
   } else if (COERCE_FROM_TO (p, M_LONG_LONG_REAL, M_LONG_LONG_COMPLEX)) {
     GENIE_UNIT (SUB (p));
     (void) nil_mp (p, DIGITS (M_LONG_LONG_REAL));
@@ -177,37 +177,37 @@ PROP_T genie_widen (NODE_T * p)
   } else if (COERCE_FROM_TO (p, M_COMPLEX, M_LONG_COMPLEX)) {
 // COMPLEX widenings.
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_complex_to_double_compl (p);
-#else
-    genie_lengthen_complex_to_mp_complex (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_complex_to_double_compl (p);
+    #else
+      genie_lengthen_complex_to_mp_complex (p);
+    #endif
     make_constant_widening (p, M_LONG_COMPLEX, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_COMPLEX, M_LONG_LONG_COMPLEX)) {
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_double_compl_to_long_mp_complex (p);
-#else
-    genie_lengthen_mp_complex_to_long_mp_complex (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_double_compl_to_long_mp_complex (p);
+    #else
+      genie_lengthen_mp_complex_to_long_mp_complex (p);
+    #endif
     make_constant_widening (p, M_LONG_LONG_COMPLEX, &self);
   } else if (COERCE_FROM_TO (p, M_BITS, M_LONG_BITS)) {
 // BITS widenings.
     GENIE_UNIT (SUB (p));
-#if (A68G_LEVEL >= 3)
-    genie_lengthen_bits_to_double_bits (p);
-#else
-    genie_lengthen_int_to_mp (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_lengthen_bits_to_double_bits (p);
+    #else
+      genie_lengthen_int_to_mp (p);
+    #endif
     make_constant_widening (p, M_LONG_BITS, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_BITS, M_LONG_LONG_BITS)) {
-#if (A68G_LEVEL >= 3)
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
-#else
-    GENIE_UNIT (SUB (p));
-    genie_lengthen_mp_to_long_mp (p);
-    make_constant_widening (p, M_LONG_LONG_BITS, &self);
-#endif
+    #if (A68G_LEVEL >= 3)
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+    #else
+      GENIE_UNIT (SUB (p));
+      genie_lengthen_mp_to_long_mp (p);
+      make_constant_widening (p, M_LONG_LONG_BITS, &self);
+    #endif
   } else if (COERCE_FROM_TO (p, M_BITS, M_ROW_BOOL) || COERCE_FROM_TO (p, M_BITS, M_FLEX_ROW_BOOL)) {
     GENIE_UNIT (SUB (p));
     A68G_BITS x;
@@ -222,33 +222,33 @@ PROP_T genie_widen (NODE_T * p)
     }
     PUSH_REF (p, z);
   } else if (COERCE_FROM_TO (p, M_LONG_BITS, M_ROW_BOOL) || COERCE_FROM_TO (p, M_LONG_BITS, M_FLEX_ROW_BOOL)) {
-#if (A68G_LEVEL >= 3)
-    GENIE_UNIT (SUB (p));
-    A68G_LONG_BITS x;
-    POP_OBJECT (p, &x, A68G_LONG_BITS);
-    A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
-    NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, A68G_LONG_BITS_WIDTH);
-    BYTE_T *base = ADDRESS (&row) + SIZE (M_BOOL) * (A68G_LONG_BITS_WIDTH - 1);
-    UNSIGNED_T bit = 1;
-    for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
-      STATUS ((A68G_BOOL *) base) = INIT_MASK;
-      VALUE ((A68G_BOOL *) base) = (BOOL_T) ((LW (VALUE (&x)) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
-    }
-    bit = 1;
-    for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
-      STATUS ((A68G_BOOL *) base) = INIT_MASK;
-      VALUE ((A68G_BOOL *) base) = (BOOL_T) ((HW (VALUE (&x)) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
-    }
-    PUSH_REF (p, z);
-#else
-    GENIE_UNIT (SUB (p));
-    genie_lengthen_long_bits_to_row_bool (p);
-#endif
+    #if (A68G_LEVEL >= 3)
+      GENIE_UNIT (SUB (p));
+      A68G_LONG_BITS x;
+      POP_OBJECT (p, &x, A68G_LONG_BITS);
+      A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
+      NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, A68G_LONG_BITS_WIDTH);
+      BYTE_T *base = ADDRESS (&row) + SIZE (M_BOOL) * (A68G_LONG_BITS_WIDTH - 1);
+      UNSIGNED_T bit = 1;
+      for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
+        STATUS ((A68G_BOOL *) base) = INIT_MASK;
+        VALUE ((A68G_BOOL *) base) = (BOOL_T) ((LW (VALUE (&x)) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
+      }
+      bit = 1;
+      for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
+        STATUS ((A68G_BOOL *) base) = INIT_MASK;
+        VALUE ((A68G_BOOL *) base) = (BOOL_T) ((HW (VALUE (&x)) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
+      }
+      PUSH_REF (p, z);
+    #else
+      GENIE_UNIT (SUB (p));
+      genie_lengthen_long_bits_to_row_bool (p);
+    #endif
   } else if (COERCE_FROM_TO (p, M_LONG_LONG_BITS, M_ROW_BOOL) || COERCE_FROM_TO (p, M_LONG_LONG_BITS, M_FLEX_ROW_BOOL)) {
-#if (A68G_LEVEL <= 2)
-    GENIE_UNIT (SUB (p));
-    genie_lengthen_long_bits_to_row_bool (p);
-#endif
+    #if (A68G_LEVEL <= 2)
+      GENIE_UNIT (SUB (p));
+      genie_lengthen_long_bits_to_row_bool (p);
+    #endif
   } else if (COERCE_FROM_TO (p, M_BYTES, M_ROW_CHAR) || COERCE_FROM_TO (p, M_BYTES, M_FLEX_ROW_CHAR)) {
     GENIE_UNIT (SUB (p));
     A68G_BYTES z;
