@@ -76,7 +76,7 @@ void genie_long_mp_max_int (NODE_T * p)
 
 void genie_long_max_real (NODE_T * p)
 {
-  unt digs = DIGITS (M_LONG_REAL);
+  int digs = DIGITS (M_LONG_REAL);
   MP_T *z = nil_mp (p, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_EXPONENT (z) = (MP_T) (MAX_MP_EXPONENT - 1);
@@ -89,7 +89,7 @@ void genie_long_max_real (NODE_T * p)
 
 void genie_long_mp_max_real (NODE_T * p)
 {
-  unt digs = DIGITS (M_LONG_LONG_REAL);
+  int digs = DIGITS (M_LONG_LONG_REAL);
   MP_T *z = nil_mp (p, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_EXPONENT (z) = (MP_T) (MAX_MP_EXPONENT - 1);
@@ -443,7 +443,7 @@ void genie_shorten_long_mp_to_mp (NODE_T * p)
 
 void genie_minus_mp (NODE_T * p)
 {
-  int size = SIZE (LHS_MODE (p));
+  size_t size = SIZE (LHS_MODE (p));
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
@@ -453,7 +453,7 @@ void genie_minus_mp (NODE_T * p)
 
 void genie_abs_mp (NODE_T * p)
 {
-  int size = SIZE (LHS_MODE (p));
+  size_t size = SIZE (LHS_MODE (p));
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_DIGIT (z, 1) = ABS (MP_DIGIT (z, 1));
@@ -463,7 +463,7 @@ void genie_abs_mp (NODE_T * p)
 
 void genie_sign_mp (NODE_T * p)
 {
-  int size = SIZE (LHS_MODE (p));
+  size_t size = SIZE (LHS_MODE (p));
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   DECREMENT_STACK_POINTER (p, size);
   PUSH_VALUE (p, SIGN (MP_DIGIT (z, 1)), A68G_INT);
@@ -911,8 +911,7 @@ void genie_shorten_mp_complex_to_complex (NODE_T * p)
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   DECREMENT_STACK_POINTER (p, 2 * size);
-  PUSH_VALUE (p, mp_to_real (p, a, digs), A68G_REAL);
-  PUSH_VALUE (p, mp_to_real (p, b, digs), A68G_REAL);
+  PUSH_COMPLEX_VALUE (p, mp_to_real (p, a, digs), mp_to_real (p, b, digs));
 }
 
 //! @brief OP LENG = (LONG COMPLEX) LONG LONG COMPLEX
@@ -953,7 +952,7 @@ void genie_shorten_long_mp_complex_to_mp_complex (NODE_T * p)
 
 void genie_re_mp_complex (NODE_T * p)
 {
-  int size = SIZE (SUB_MOID (p));
+  size_t size = SIZE (SUB_MOID (p));
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_STATUS (a) = (MP_T) INIT_MASK;
   DECREMENT_STACK_POINTER (p, size);
@@ -976,7 +975,7 @@ void genie_im_mp_complex (NODE_T * p)
 
 void genie_minus_mp_complex (NODE_T * p)
 {
-  int size = SIZE_COMPL (SUB_MOID (p));
+  size_t size = SIZE_COMPL (SUB_MOID (p));
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_DIGIT (a, 1) = -MP_DIGIT (a, 1);
@@ -989,7 +988,7 @@ void genie_minus_mp_complex (NODE_T * p)
 
 void genie_conj_mp_complex (NODE_T * p)
 {
-  int size = SIZE_COMPL (SUB_MOID (p));
+  size_t size = SIZE_COMPL (SUB_MOID (p));
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_DIGIT (b, 1) = -MP_DIGIT (b, 1);
