@@ -1099,7 +1099,7 @@ char *gen_basic_conditional (NODE_T * p, FILE_T out, int compose_fun)
     undent (out, ") {\n");
     A68G_OPT (indentation)++;
   } else {
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   FORWARD (p);
   if (IS (p, THEN_PART) || IS (p, CHOICE)) {
@@ -1108,7 +1108,7 @@ char *gen_basic_conditional (NODE_T * p, FILE_T out, int compose_fun)
     A68G_OPT (indentation)--;
     A68G_OPT (cse_pointer) = pop;
   } else {
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   FORWARD (p);
   if (IS (p, ELSE_PART) || IS (p, CHOICE)) {
@@ -1613,7 +1613,7 @@ char *gen_unit (NODE_T * p, FILE_T out, int compose_fun)
 #define COMPILE(p, out, fun, compose_fun) {\
   char * fn = (fun) (p, out, compose_fun);\
   if (compose_fun == A68G_MAKE_FUNCTION && fn != NO_TEXT) {\
-    ABEND (strlen (fn) >= NAME_SIZE, ERROR_INTERNAL_CONSISTENCY, __func__);\
+    ABEND (strlen (fn) >= NAME_SIZE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);\
     COMPILE_NAME (GINFO (p)) = new_string (fn, NO_TEXT);\
     if (SUB (p) != NO_NODE && COMPILE_NODE (GINFO (SUB (p))) > 0) {\
       COMPILE_NODE (GINFO (p)) = COMPILE_NODE (GINFO (SUB (p)));\
@@ -1644,7 +1644,7 @@ char *gen_unit (NODE_T * p, FILE_T out, int compose_fun)
     } else if (IS (p, CONDITIONAL_CLAUSE)) {
       char *fn2 = gen_basic_conditional (p, out, compose_fun);
       if (compose_fun == A68G_MAKE_FUNCTION && fn2 != NO_TEXT) {
-        ABEND (strlen (fn2) >= NAME_SIZE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (strlen (fn2) >= NAME_SIZE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
         COMPILE_NAME (GINFO (p)) = new_string (fn2, NO_TEXT);
         if (SUB (p) != NO_NODE && COMPILE_NODE (GINFO (SUB (p))) > 0) {
           COMPILE_NODE (GINFO (p)) = COMPILE_NODE (GINFO (SUB (p)));
@@ -1727,7 +1727,7 @@ char *gen_basic (NODE_T * p, FILE_T out)
 #define COMPILE(p, out, fun) {\
   char * fn = (fun) (p, out);\
   if (fn != NO_TEXT) {\
-    ABEND (strlen (fn) >= NAME_SIZE, ERROR_INTERNAL_CONSISTENCY, __func__);\
+    ABEND (strlen (fn) >= NAME_SIZE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);\
     COMPILE_NAME (GINFO (p)) = new_string (fn, NO_TEXT);\
     if (SUB (p) != NO_NODE && COMPILE_NODE (GINFO (SUB (p))) > 0) {\
       COMPILE_NODE (GINFO (p)) = COMPILE_NODE (GINFO (SUB (p)));\
