@@ -286,7 +286,7 @@ TRANSLATION constants[] = {
   {genie_real_shorths, "1"},
   {genie_complex_lengths, "3"},
   {genie_complex_shorths, "1"},
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
   {genie_bits_lengths, "2"},
 #else
   {genie_bits_lengths, "3"},
@@ -294,25 +294,25 @@ TRANSLATION constants[] = {
   {genie_bits_shorths, "1"},
   {genie_bytes_lengths, "2"},
   {genie_bytes_shorths, "1"},
-  {genie_int_width, "A68_INT_WIDTH"},
-  {genie_long_int_width, "A68_LONG_INT_WIDTH"},
-  {genie_long_mp_int_width, "A68_LONG_LONG_INT_WIDTH"},
-  {genie_real_width, "A68_REAL_WIDTH"},
-  {genie_long_real_width, "A68_LONG_REAL_WIDTH"},
-  {genie_long_mp_real_width, "A68_LONG_LONG_REAL_WIDTH"},
-  {genie_exp_width, "A68_EXP_WIDTH"},
-  {genie_long_exp_width, "A68_LONG_EXP_WIDTH"},
-  {genie_long_mp_exp_width, "A68_LONG_LONG_EXP_WIDTH"},
-  {genie_bits_width, "A68_BITS_WIDTH"},
-  {genie_bytes_width, "A68_BYTES_WIDTH"},
-  {genie_long_bytes_width, "A68_LONG_BYTES_WIDTH"},
+  {genie_int_width, "A68G_INT_WIDTH"},
+  {genie_long_int_width, "A68G_LONG_INT_WIDTH"},
+  {genie_long_mp_int_width, "A68G_LONG_LONG_INT_WIDTH"},
+  {genie_real_width, "A68G_REAL_WIDTH"},
+  {genie_long_real_width, "A68G_LONG_REAL_WIDTH"},
+  {genie_long_mp_real_width, "A68G_LONG_LONG_REAL_WIDTH"},
+  {genie_exp_width, "A68G_EXP_WIDTH"},
+  {genie_long_exp_width, "A68G_LONG_EXP_WIDTH"},
+  {genie_long_mp_exp_width, "A68G_LONG_LONG_EXP_WIDTH"},
+  {genie_bits_width, "A68G_BITS_WIDTH"},
+  {genie_bytes_width, "A68G_BYTES_WIDTH"},
+  {genie_long_bytes_width, "A68G_LONG_BYTES_WIDTH"},
   {genie_max_abs_char, "UCHAR_MAX"},
-  {genie_max_int, "A68_MAX_INT"},
-  {genie_max_real, "A68_REAL_MAX"},
-  {genie_min_real, "A68_REAL_MIN"},
+  {genie_max_int, "A68G_MAX_INT"},
+  {genie_max_real, "A68G_REAL_MAX"},
+  {genie_min_real, "A68G_REAL_MIN"},
   {genie_null_char, "NULL_CHAR"},
-  {genie_small_real, "A68_REAL_EPS"},
-  {genie_pi, "A68_PI"},
+  {genie_small_real, "A68G_REAL_EPS"},
+  {genie_pi, "A68G_PI"},
 
 #if defined (HAVE_GSL)
 
