@@ -102,13 +102,13 @@ void genie_pq_connectdb (NODE_T * p)
   CONNECTION (file) = PQconnectdb (a_to_c_string (p, DEREF (char, &ref_z), conninfo));
   RESULT (file) = NO_PGRESULT;
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
   (void) PQsetErrorVerbosity (CONNECTION (file), PQERRORS_DEFAULT);
   if (PQstatus (CONNECTION (file)) != CONNECTION_OK) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   }
 }
 
@@ -122,7 +122,7 @@ void genie_pq_finish (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) != NO_PGRESULT) {
@@ -131,7 +131,7 @@ void genie_pq_finish (NODE_T * p)
   PQfinish (CONNECTION (file));
   CONNECTION (file) = NO_PGCONN;
   RESULT (file) = NO_PGRESULT;
-  PUSH_PRIMAL (p, 0, INT);
+  PUSH_VALUE (p, 0, A68G_INT);
 }
 
 //! @brief PROC pq reset (REF FILE) VOID
@@ -144,14 +144,14 @@ void genie_pq_reset (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) != NO_PGRESULT) {
     PQclear (RESULT (file));
   }
   PQreset (CONNECTION (file));
-  PUSH_PRIMAL (p, 0, INT);
+  PUSH_VALUE (p, 0, A68G_INT);
 }
 
 //! @brief PROC pq exec = (REF FILE, STRING) INT
@@ -165,7 +165,7 @@ void genie_pq_exec (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) != NO_PGRESULT) {
@@ -175,9 +175,9 @@ void genie_pq_exec (NODE_T * p)
   RESULT (file) = PQexec (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), query));
   if ((PQresultStatus (RESULT (file)) != PGRES_TUPLES_OK)
       && (PQresultStatus (RESULT (file)) != PGRES_COMMAND_OK)) {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   }
 }
 
@@ -192,15 +192,15 @@ void genie_pq_parameterstatus (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, parameter));
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, (char *) PQparameterStatus (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), parameter)), DEFAULT_WIDTH);
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -214,19 +214,19 @@ void genie_pq_cmdstatus (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQcmdStatus (RESULT (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -240,19 +240,19 @@ void genie_pq_cmdtuples (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQcmdTuples (RESULT (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -266,14 +266,14 @@ void genie_pq_ntuples (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
-  PUSH_PRIMAL (p, (PQresultStatus (RESULT (file))) == PGRES_TUPLES_OK ? PQntuples (RESULT (file)) : -3, INT);
+  PUSH_VALUE (p, (PQresultStatus (RESULT (file))) == PGRES_TUPLES_OK ? PQntuples (RESULT (file)) : -3, A68G_INT);
 }
 
 //! @brief PROC pq nfields (REF FILE) INT
@@ -286,14 +286,14 @@ void genie_pq_nfields (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
-  PUSH_PRIMAL (p, (PQresultStatus (RESULT (file))) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : -3, INT);
+  PUSH_VALUE (p, (PQresultStatus (RESULT (file))) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : -3, A68G_INT);
 }
 
 //! @brief PROC pq fname (REF FILE, INT) INT
@@ -308,11 +308,11 @@ void genie_pq_fname (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
@@ -324,7 +324,7 @@ void genie_pq_fname (NODE_T * p)
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68g_index) - 1), DEFAULT_WIDTH);
     STRPOS (file) = 0;
   }
-  PUSH_PRIMAL (p, 0, INT);
+  PUSH_VALUE (p, 0, A68G_INT);
 }
 
 //! @brief PROC pq fnumber = (REF FILE, STRING) INT
@@ -338,19 +338,19 @@ void genie_pq_fnumber (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
   A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, name));
   int k = PQfnumber (RESULT (file), a_to_c_string (p, DEREF (char, &ref_z), name));
   if (k == -1) {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, k + 1, INT);
+    PUSH_VALUE (p, k + 1, A68G_INT);
   }
 }
 
@@ -366,11 +366,11 @@ void genie_pq_fformat (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
@@ -378,7 +378,7 @@ void genie_pq_fformat (NODE_T * p)
     diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  PUSH_PRIMAL (p, PQfformat (RESULT (file), VALUE (&a68g_index) - 1), INT);
+  PUSH_VALUE (p, PQfformat (RESULT (file), VALUE (&a68g_index) - 1), A68G_INT);
 }
 
 //! @brief PROC pq getvalue (REF FILE, INT, INT) INT
@@ -395,11 +395,11 @@ void genie_pq_getvalue (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
@@ -420,9 +420,9 @@ void genie_pq_getvalue (NODE_T * p)
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -440,11 +440,11 @@ void genie_pq_getisnull (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
@@ -457,7 +457,7 @@ void genie_pq_getisnull (NODE_T * p)
     diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  PUSH_PRIMAL (p, PQgetisnull (RESULT (file), VALUE (&row) - 1, VALUE (&column) - 1), INT);
+  PUSH_VALUE (p, PQgetisnull (RESULT (file), VALUE (&row) - 1, VALUE (&column) - 1), A68G_INT);
 }
 
 //! @brief Edit error message string from libpq.
@@ -522,7 +522,7 @@ void genie_pq_errormessage (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
@@ -538,9 +538,9 @@ void genie_pq_errormessage (NODE_T * p)
     }
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -554,11 +554,11 @@ void genie_pq_resulterrormessage (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (RESULT (file) == NO_PGRESULT) {
-    PUSH_PRIMAL (p, -2, INT);
+    PUSH_VALUE (p, -2, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
@@ -574,9 +574,9 @@ void genie_pq_resulterrormessage (NODE_T * p)
     }
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -590,15 +590,15 @@ void genie_pq_db (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQdb (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -612,15 +612,15 @@ void genie_pq_user (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQuser (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -634,15 +634,15 @@ void genie_pq_pass (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQpass (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -656,15 +656,15 @@ void genie_pq_host (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQhost (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -678,15 +678,15 @@ void genie_pq_port (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQport (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -700,15 +700,15 @@ void genie_pq_tty (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQtty (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -722,15 +722,15 @@ void genie_pq_options (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQoptions (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
-    PUSH_PRIMAL (p, 0, INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -744,13 +744,13 @@ void genie_pq_protocolversion (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    PUSH_PRIMAL (p, PQprotocolVersion (CONNECTION (file)), INT);
+    PUSH_VALUE (p, PQprotocolVersion (CONNECTION (file)), A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -764,13 +764,13 @@ void genie_pq_serverversion (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    PUSH_PRIMAL (p, PQserverVersion (CONNECTION (file)), INT);
+    PUSH_VALUE (p, PQserverVersion (CONNECTION (file)), A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -784,13 +784,13 @@ void genie_pq_socket (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    PUSH_PRIMAL (p, PQsocket (CONNECTION (file)), INT);
+    PUSH_VALUE (p, PQsocket (CONNECTION (file)), A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
@@ -804,13 +804,13 @@ void genie_pq_backendpid (NODE_T * p)
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
-    PUSH_PRIMAL (p, -1, INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    PUSH_PRIMAL (p, PQbackendPID (CONNECTION (file)), INT);
+    PUSH_VALUE (p, PQbackendPID (CONNECTION (file)), A68G_INT);
   } else {
-    PUSH_PRIMAL (p, -3, INT);
+    PUSH_VALUE (p, -3, A68G_INT);
   }
 }
 
