@@ -521,7 +521,7 @@ void genie_get_sound (NODE_T * p)
   }
   n = A68G_SOUND_BYTES (&w);
   addr = ((VALUE (&sample) - 1) * (int) (NUM_CHANNELS (&w)) + (VALUE (&channel) - 1)) * n;
-  ABEND (addr < 0 || addr >= (int) DATA_SIZE (&w), ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (addr < 0 || addr >= (int) DATA_SIZE (&w), ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   d = &(ADDRESS (&(DATA (&w)))[addr]);
 // Convert from little-endian, irrespective from the platform we work on.
   for (k = 0, z = 0, m = 0; k < n; k++) {
@@ -557,7 +557,7 @@ void genie_set_sound (NODE_T * p)
   }
   n = A68G_SOUND_BYTES (&w);
   addr = ((VALUE (&sample) - 1) * (int) (NUM_CHANNELS (&w)) + (VALUE (&channel) - 1)) * n;
-  ABEND (addr < 0 || addr >= (int) DATA_SIZE (&w), ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (addr < 0 || addr >= (int) DATA_SIZE (&w), ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   d = &(ADDRESS (&(DATA (&w)))[addr]);
 // Convert to little-endian.
   for (k = 0, z = VALUE (&value); k < n; k++) {
