@@ -1493,7 +1493,9 @@ void transput_error (NODE_T * p, A68G_REF ref_file, MOID_T * m)
 
 int char_scanner (A68G_FILE * f)
 {
-  if (get_transput_buffer_index (TRANSPUT_BUFFER (f)) > 0) {
+  if (FD (f) == A68G_STDIN && A68G (stdin_is_raw)) {
+    return peek_char (A68G_PEEK_READ); 
+  } else if (get_transput_buffer_index (TRANSPUT_BUFFER (f)) > 0) {
 // There are buffered characters.
     END_OF_FILE (f) = A68G_FALSE;
     return pop_char_transput_buffer (TRANSPUT_BUFFER (f));
@@ -1704,3 +1706,58 @@ void genie_space (NODE_T * p)
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
 }
+
+//! @brief PROC (REF FILE) VOID raw
+
+void genie_kbd_raw (NODE_T * p)
+{
+  A68G_REF ref_file;
+  POP_REF (p, &ref_file);
+  CHECK_REF (p, ref_file, M_REF_FILE);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
+  CHECK_INIT (p, INITIALISED (file), M_FILE);
+  if (!OPENED (file)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_NOT_OPEN);
+    exit_genie (p, A68G_RUNTIME_ERROR);
+  }
+  if (DRAW_MOOD (file)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_WRONG_MOOD, "draw");
+    exit_genie (p, A68G_RUNTIME_ERROR);
+  }
+  if (WRITE_MOOD (file)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_WRONG_MOOD, "write");
+    exit_genie (p, A68G_RUNTIME_ERROR);
+  }
+  if (FD (file) == A68G_STDIN) {
+    READ_MOOD (file) = A68G_TRUE;
+    peek_char (A68G_PEEK_INIT);
+  }
+}
+
+//! @brief PROC (REF FILE) VOID cooked
+
+void genie_kbd_cooked (NODE_T * p)
+{
+  A68G_REF ref_file;
+  POP_REF (p, &ref_file);
+  CHECK_REF (p, ref_file, M_REF_FILE);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
+  CHECK_INIT (p, INITIALISED (file), M_FILE);
+  if (!OPENED (file)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_NOT_OPEN);
+    exit_genie (p, A68G_RUNTIME_ERROR);
+  }
+  if (DRAW_MOOD (file)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_WRONG_MOOD, "draw");
+    exit_genie (p, A68G_RUNTIME_ERROR);
+  }
+  if (WRITE_MOOD (file)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_WRONG_MOOD, "write");
+    exit_genie (p, A68G_RUNTIME_ERROR);
+  }
+  if (READ_MOOD (file)) {
+    if (FD (file) == A68G_STDIN) {
+      peek_char (A68G_PEEK_RESET);
+    }
+  }
+}
