@@ -1737,7 +1737,7 @@ char *whole (NODE_T * p)
     PUSH_UNION (p, (void *) M_LONG_LONG_INT);
     MP_T *z = nil_mp (p, digits);
     (void) int_to_mp (p, z, x, digits);
-    PUSH_PRIMAL (p, VALUE (&width), INT);
+    PUSH_VALUE (p, VALUE (&width), A68G_INT);
     return whole (p);
   }
   #if (A68G_LEVEL >= 3)
@@ -1747,7 +1747,7 @@ char *whole (NODE_T * p)
       PUSH_UNION (p, (void *) M_LONG_LONG_INT);
       MP_T *z = nil_mp (p, digits);
       (void) double_int_to_mp (p, z, x, digits);
-      PUSH_PRIMAL (p, VALUE (&width), INT);
+      PUSH_VALUE (p, VALUE (&width), A68G_INT);
       return whole (p);
     }
   #endif
@@ -1907,8 +1907,8 @@ char *fixed (NODE_T * p)
       #else
         (void) real_to_mp (p, z, x, digits);
       #endif
-      PUSH_PRIMAL (p, VALUE (&width), INT);
-      PUSH_PRIMAL (p, VALUE (&after), INT);
+      PUSH_VALUE (p, VALUE (&width), A68G_INT);
+      PUSH_VALUE (p, VALUE (&after), A68G_INT);
       return fixed (p);
     }
   }
@@ -1919,8 +1919,8 @@ char *fixed (NODE_T * p)
       PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
       MP_T *z = nil_mp (p, digits);
       (void) double_int_to_mp (p, z, x, digits);
-      PUSH_PRIMAL (p, VALUE (&width), INT);
-      PUSH_PRIMAL (p, VALUE (&after), INT);
+      PUSH_VALUE (p, VALUE (&width), A68G_INT);
+      PUSH_VALUE (p, VALUE (&after), A68G_INT);
       return fixed (p);
     } else if (mode == M_LONG_REAL) {
       DOUBLE_T x = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))).f;
@@ -1934,8 +1934,8 @@ char *fixed (NODE_T * p)
         PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
         MP_T *z = nil_mp (p, digits);
         (void) double_to_mp (p, z, x, A68G_DOUBLE_DIG, A68G_TRUE, digits);
-        PUSH_PRIMAL (p, VALUE (&width), INT);
-        PUSH_PRIMAL (p, VALUE (&after), INT);
+        PUSH_VALUE (p, VALUE (&width), A68G_INT);
+        PUSH_VALUE (p, VALUE (&after), A68G_INT);
         return fixed (p);
       }
     }
@@ -2102,10 +2102,10 @@ char *real (NODE_T * p)
       #else
         (void) real_to_mp (p, z, x, digits);
       #endif
-      PUSH_PRIMAL (p, VALUE (&width), INT);
-      PUSH_PRIMAL (p, VALUE (&after), INT);
-      PUSH_PRIMAL (p, VALUE (&expo), INT);
-      PUSH_PRIMAL (p, VALUE (&frmt), INT);
+      PUSH_VALUE (p, VALUE (&width), A68G_INT);
+      PUSH_VALUE (p, VALUE (&after), A68G_INT);
+      PUSH_VALUE (p, VALUE (&expo), A68G_INT);
+      PUSH_VALUE (p, VALUE (&frmt), A68G_INT);
       return real (p);
     }
   }
@@ -2116,10 +2116,10 @@ char *real (NODE_T * p)
       PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
       MP_T *z = nil_mp (p, digits);
       (void) double_int_to_mp (p, z, k, digits);
-      PUSH_PRIMAL (p, VALUE (&width), INT);
-      PUSH_PRIMAL (p, VALUE (&after), INT);
-      PUSH_PRIMAL (p, VALUE (&expo), INT);
-      PUSH_PRIMAL (p, VALUE (&frmt), INT);
+      PUSH_VALUE (p, VALUE (&width), A68G_INT);
+      PUSH_VALUE (p, VALUE (&after), A68G_INT);
+      PUSH_VALUE (p, VALUE (&expo), A68G_INT);
+      PUSH_VALUE (p, VALUE (&frmt), A68G_INT);
       return real (p);
     } else if (mode == M_LONG_REAL) {
       DOUBLE_T x = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))).f;
@@ -2133,10 +2133,10 @@ char *real (NODE_T * p)
         PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
         MP_T *z = nil_mp (p, digits);
         (void) double_to_mp (p, z, (DOUBLE_T) x, A68G_DOUBLE_DIG, A68G_TRUE, digits);
-        PUSH_PRIMAL (p, VALUE (&width), INT);
-        PUSH_PRIMAL (p, VALUE (&after), INT);
-        PUSH_PRIMAL (p, VALUE (&expo), INT);
-        PUSH_PRIMAL (p, VALUE (&frmt), INT);
+        PUSH_VALUE (p, VALUE (&width), A68G_INT);
+        PUSH_VALUE (p, VALUE (&after), A68G_INT);
+        PUSH_VALUE (p, VALUE (&expo), A68G_INT);
+        PUSH_VALUE (p, VALUE (&frmt), A68G_INT);
         return real (p);
       }
     }
