@@ -907,7 +907,7 @@ void genie_mul_complex (NODE_T * p)
   REAL_T re = VALUE (&re_x) * VALUE (&re_y) - VALUE (&im_x) * VALUE (&im_y);
   REAL_T im = VALUE (&im_x) * VALUE (&re_y) + VALUE (&re_x) * VALUE (&im_y);
   CHECK_COMPLEX (p, re, im);
-  PUSH_COMPLEX (p, re, im);
+  PUSH_COMPLEX_VALUE (p, re, im);
 }
 
 // OP / = (COMPLEX, COMPLEX) COMPLEX
@@ -931,7 +931,7 @@ void genie_div_complex (NODE_T * p)
     im = (VALUE (&im_x) * r - VALUE (&re_x)) / den;
   }
   CHECK_COMPLEX (p, re, im);
-  PUSH_COMPLEX (p, re, im);
+  PUSH_COMPLEX_VALUE (p, re, im);
 }
 
 // OP ** = (COMPLEX, INT) COMPLEX
