@@ -134,6 +134,10 @@
 #define A68G_GC_SAFE 1
 #define A68G_GC_HALT 2
 
+#define A68G_PEEK_INIT 0x01
+#define A68G_PEEK_READ 0x02
+#define A68G_PEEK_RESET 0x04
+
 // Macros
 
 #define _SKIP_ {(void) 0;}
